//Author's solution of the problem "Lehmer"

using namespace std;
#include <set>
#include <ctime>
#include <vector>
#include <cassert>
#include <fstream>
#include <iterator>
#include <iostream>
#include <algorithm>

class NBinaryTree
{
public:
	NBinaryTree(int n)
	{
		int sz = 1;
		while(sz <= n)
		{
			sz *= 2;
		}

		node_.resize(sz);
		Construct(0, 1, n);
	}

	int Query(int pi)
	{
		return Query(0, pi);
	}

	void Erase(int pi)
	{
		Erase(0, pi);
	}

private:
	static const int NIL = -1;
	struct Node
	{
		int value;
		bool valid;
		int subtreeSize;
		Node(): value(NIL), valid(true), subtreeSize(0) {}
	};

	std::vector<Node> node_;
	void Construct(int pos, int begin, int end)
	{
		int value = (begin + end) / 2;
		node_[pos].value = value;
		node_[pos].subtreeSize = end - begin + 1;
		if(begin != end)
		{
			int lbegin = begin;
			int lend = value - 1;
			if(lbegin <= lend)
			{
				Construct(pos * 2 + 1, lbegin, lend);
			}

			int rbegin = value + 1;
			int rend = end;
			if(rbegin <= rend)
			{
				Construct(pos * 2 + 2, rbegin, rend);
			}
		}
	}

	int Query(int pos, int value)
	{
		if(pos < node_.size() && node_[pos].value != NIL)
		{
			int nowValue = node_[pos].value;
			if(value <= nowValue)
			{
				return Query(pos * 2 + 1, value);		
			}

			int add = (pos * 2 + 1 < node_.size() ? node_[pos * 2 + 1].subtreeSize : 0) + (node_[pos].valid ? 1 : 0);
			return add + Query(pos * 2 + 2, value);
		}

		return 0;		
	}

	void Erase(int pos, int value)
	{
		if(pos < node_.size() && node_[pos].value != NIL)
		{			
			--node_[pos].subtreeSize;
			if(value > node_[pos].value)
			{
				Erase(pos * 2 + 2, value);
			}
			else if(value < node_[pos].value)
			{
				Erase(pos * 2 + 1, value);
			}
			else
			{
				node_[pos].valid = false;
			}
		}
	}
};

std::vector<int> BruteForce(const std::vector<int> & p)
{
	std::vector<int> l(p.size(), 0);
	for(size_t i = 0; i < p.size(); i++)
	{
		for(size_t j = i + 1; j < p.size(); j++)
		{
			l[i] += p[j] < p[i] ? 1 : 0;
		}
	}

	return l;
}

int main(int argc, char * argv[])
{
	int test;
	for(cin >> test; test > 0; --test)
	{
		int n;
		cin >> n;
		NBinaryTree tree(n);
		std::vector<int> p(n);
		std::vector<int> l(n);
		copy_n(std::istream_iterator<int>(std::cin), n, p.begin());
#ifdef _DEBUG
		std::set<int> s(p.begin(), p.end());
		assert(p.size() == s.size());
#endif
		for(int i = 0; i < n; i++)
		{
			l[i] = tree.Query(p[i]);
			tree.Erase(p[i]);
		}

#ifdef _DEBUG
		assert(l == BruteForce(p));
#endif
		std::copy(l.begin(), l.end(), std::ostream_iterator<int>(std::cout, " "));
		std::cout << std::endl;
	}

	std::cerr << "Time: " << double(clock()) / 1000 << std::endl;
	return 0;
}