#include <iostream>
#include <climits>
#include <complex>
#include <algorithm>
#include <iomanip>

using namespace std;

typedef complex<double> V;

int n, z1, z2;
V xy[100];
double z[100];

bool ccw(V a, V b, V c) {
	return ((c - a) * conj(b - a)).imag() > 0;
}

double laske(double cz) {
	vector<V> pts;
	for(int i = 0; i < n; ++i) {
		if(z[i] == cz) pts.push_back(xy[i]);
		
		for(int j = i + 1; j < n; ++j) {
			if((z[i] < cz) == (z[j] < cz)) continue;
			
			double t = (cz - z[i]) / (z[j] - z[i]);
			
			V p = (1 - t) * xy[i] + t * xy[j];
			pts.push_back(p);
		}
	}
	
	sort(
		pts.begin(), pts.end(),
		[](V a, V b) {
			return make_pair(a.real(), a.imag()) < make_pair(b.real(), b.imag());
		}
	);
	
	pts.erase(unique(pts.begin(), pts.end()), pts.end());
	int n = pts.size();
	if(n <= 2) return 0.0;
	
	vector<V> hull;
	hull.push_back(pts[0]);
	for(int dir = 0; dir < 2; ++dir) {
		if(dir) reverse(pts.begin(), pts.end());
		
		int start = hull.size();
		for(int i = 1; i < n; ++i) {
			while(hull.size() > start && !ccw(hull[hull.size() - 2], hull.back(), pts[i])) {
				hull.pop_back();
			}
			hull.push_back(pts[i]);
		}
	}
	
	double ret = 0.0;
	
	for(int i = 1; i < hull.size(); ++i) {
		ret += hull[i - 1].real() * hull[i].imag() - hull[i].real() * hull[i - 1].imag();
	}
	
	return fabs(0.5 * ret);
}

int main() {
	cin.sync_with_stdio(false);
	
	cin >> n >> z1 >> z2;
	
	for(int i = 0; i < n; ++i) {
		double x, y;
		cin >> x >> y >> z[i];
		xy[i] = V(x, y);
	}
	
	for(int cz = z1; cz <= z2; ++cz) {
		cout << fixed << setprecision(20) << laske(cz) << "\n";
	}
	
	return 0;
}
